@@ -2,7 +2,7 @@
  * Copyright (c) 1995-2003, Index Data.
  * See the file LICENSE for details.
  *
- * $Id: ztest.c,v 1.57 2003/03/24 22:26:51 adam Exp $
+ * $Id: ztest.c,v 1.59 2003/12/29 14:54:33 adam Exp $
  */
 
 /*
@@ -386,6 +386,10 @@ int ztest_esrequest (void *handle, bend_esrequest_rr *rr)
 	    }
 	}
     }
+    else if (rr->esr->taskSpecificParameters->which == Z_External_update0)
+    {
+	yaz_log(LOG_LOG, "Received DB Update (version 0)");
+    }
     else
     {
         yaz_log (LOG_WARN, "Unknown Extended Service(%d)",
@@ -598,12 +602,15 @@ int ztest_scan(void *handle, bend_scan_rr *q)
 
 static int ztest_explain(void *handle, bend_explain_rr *rr)
 {
-    rr->explain_buf = "<explain>\n"
-        "\t<serverInfo>\n"
-        "\t\t<host>localhost</host>\n"
-        "\t\t<port>210</port>\n"
-        "\t</serverInfo>\n"
-        "</explain>\n";
+    if (rr->database && !strcmp(rr->database, "Default"))
+    {
+	rr->explain_buf = "<explain>\n"
+	    "\t<serverInfo>\n"
+	    "\t\t<host>localhost</host>\n"
+	    "\t\t<port>210</port>\n"
+	    "\t</serverInfo>\n"
+	    "</explain>\n";
+    }
     return 0;
 }
 
